import request from '@/utils/request'

// 查询女神列表列表
export function listAnchor(query) {
  return request({
    url: '/cai/anchor/list',
    method: 'get',
    params: query
  })
}

// 查询女神列表详细
export function getAnchor(id) {
  return request({
    url: '/cai/anchor/' + id,
    method: 'get'
  })
}

export function getFullAnchor(id) {
  return request({
    url: '/cai/anchor/full',
    method: 'get',
    params: {userId:id}
  })
}

// 新增女神列表
export function addAnchor(data) {
  return request({
    url: '/cai/anchor',
    method: 'post',
    data: data
  })
}

// 修改女神列表
export function updateAnchor(data) {
  return request({
    url: '/cai/anchor',
    method: 'put',
    data: data
  })
}

export function updateVideoStatusOnline(data) {
  return request({
    url: '/cai/anchor/updateVideoStatusOnline',
    method: 'post',
    data: data
  })
}

// 删除女神列表
export function delAnchor(id) {
  return request({
    url: '/cai/anchor/' + id,
    method: 'delete'
  })
}
