<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item :label="systemName+'号'" prop="usercode">
        <el-input
            v-model="queryParams.usercode"
            :placeholder="'请输入'+systemName+'号'"
            clearable
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="手机号" prop="mobile">
        <el-input
            v-model="queryParams.mobile"
            placeholder="请输入手机号"
            clearable
            @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="IM在线" prop="onlineStatus">
        <el-select v-model="queryParams.onlineStatus" clearable size="small">
          <el-option
              v-for="dict in onlineStatusList"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
              @keyup.enter.native="handleQuery"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="价格" prop="price">
        <el-input-number size="mini" v-model="queryParams.startPrice" :min="0" :step="100" @keyup.enter.native="handleQuery"></el-input-number> -
        <el-input-number size="mini" v-model="queryParams.endPrice" :min="0" :step="100" @keyup.enter.native="handleQuery"></el-input-number>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['cai:anchor:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
            type="danger"
            plain
            icon="el-icon-plus"
            size="mini"
            @click="handleAnchorTop"
            v-hasPermi="['cai:anchorTop:add']"
        >新增主播置顶
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
            type="info"
            plain
            icon="el-icon-query"
            size="mini"
            @click="handleAnchorTopList"
            v-hasPermi="['cai:anchorTop:list']"
        >主播置顶快速查询
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="anchorList" @selection-change="handleSelectionChange">
<!--      <el-table-column type="selection" width="55" align="center" />-->
      <el-table-column :label="systemName+'号'" align="center" prop="usercode" />
      <el-table-column label="昵称" align="center" prop="nickname" />
      <el-table-column label="手机" align="center" prop="mobile" width="120"/>
      <el-table-column label="头像" align="center" prop="avatar" >
        <template v-slot="scope">
          <image-avatar :src="scope.row.avatar"/>
        </template>
      </el-table-column>
      <el-table-column label="性别" align="center" prop="gender">
        <template v-slot="scope">
          <cai-dict-tag :options="genderList" :value="scope.row.gender" />
        </template>
      </el-table-column>
      <el-table-column label="年龄" align="center" prop="age" />
      <el-table-column label="所在城市" align="center" prop="city" />
      <el-table-column label="允许群发" align="center" prop="enableGreet" >
        <template v-slot="scope">
          <el-switch
              v-model="scope.row.enableGreet"
              :active-value="1"
              :inactive-value="0"
              @change="handleEnableGreetChange(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="开启视频" align="center" prop="openVideoStatus" >
        <template v-slot="scope">
          <el-switch
              v-model="scope.row.openVideoStatus"
              :active-value="1"
              :inactive-value="0"
              @change="handleOpenVideoStatusChange(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="视频状态" align="center" prop="videoStatus" >
        <template v-slot="scope">
          <el-tag :key="1" :index="1" type="danger" v-if="scope.row.videoStatus === 1" class="click-class" @click="updateVideoStatusHandle(scope.row)">视频中</el-tag>
          <el-tag :key="2" :index="2" type="info" v-if="scope.row.videoStatus === 0">休息中</el-tag>
        </template>
      </el-table-column>
      <el-table-column label="首页展示" align="center" prop="indexDisplay" >
        <template v-slot="scope">
          <el-switch
              v-model="scope.row.indexDisplay"
              :active-value="1"
              :inactive-value="0"
              @change="handleIndexDisplayChange(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="推荐" align="center" prop="recommendStatus" >
        <template v-slot="scope">
          <el-switch
              v-model="scope.row.recommendStatus"
              :active-value="1"
              :inactive-value="0"
              @change="handleRecommendStatusChange(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
<!--      <el-table-column label="评分" align="center" prop="giveScore" />-->
      <el-table-column label="你懂的(%)" align="center" prop="showMeRate" />
      <el-table-column label="黑户标记" align="center" prop="hiddenStatus" :render-header="hiddenStatusRenderHeader" >
        <template v-slot="scope">
          <el-switch
              v-model="scope.row.hiddenStatus"
              :active-value="1"
              :inactive-value="0"
              @change="handleHiddenStatusChange(scope.row)"
          ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="价格" align="center" prop="price" />
<!--      <el-table-column label="视频分成" align="center" prop="videoRate" />
      <el-table-column label="守护分成" align="center" prop="guardRate" />
      <el-table-column label="礼物分成" align="center" prop="giftRate" />-->
      <el-table-column label="服务总次数" align="center" prop="serviceCount" />
      <el-table-column label="服务总时长" align="center" prop="serviceTime" />
      <el-table-column label="IM在线" align="center" prop="onlineStatus" >
        <template v-slot="scope">
          <cai-dict-tag :options="onlineStatusList" :value="scope.row.onlineStatus" />
        </template>
      </el-table-column>
      <el-table-column label="状态" align="center" prop="status" >
        <template v-slot="scope">
          <cai-dict-tag :options="userStatusList" :value="scope.row.status" />
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" fixed="right" width="180">
        <template v-slot="scope">
          <el-button
              size="mini"
              type="text"
              icon="el-icon-info"
              @click="handleAnchorInfo(scope.row)"
              v-hasPermi="['cai:anchor:query']"
          >详情</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['cai:anchor:edit']"
          >修改</el-button>
          <el-button
              size="mini"
              type="text"
              icon="el-icon-delete"
              @click="handleDelete(scope.row)"
              v-hasPermi="['cai:anchor:remove']"
          >取消</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <add-anchor-dialog v-if="addAnchorDialogVisible" ref="addAnchorDialog" @refreshDataList="getList"  />
    <update-anchor-dialog v-if="updateAnchorDialogVisible" ref="updateAnchorDialog" @refreshDataList="getList" />
    <anchor-info-dialog v-if="anchorInfoDialogVisible" ref="anchorInfoDialog" />
    <add-anchor-top-dialog v-if="addAnchorTopDialogVisible" ref="addAnchorTopDialog" @refreshDataList="getList" />
    <anchor-top-dialog v-if="anchorTopDialogVisible" ref="anchorTopDialog"  />
  </div>
</template>

<script>
import {delAnchor, listAnchor, updateAnchor, updateVideoStatusOnline} from '@/api/cai/anchor'
import {genderList, onlineStatusList, userStatusList, videoStatusList} from '@/constant/statusMap'
import AddAnchorDialog from "@/views/cai/anchor/add-anchor-dialog";
import UpdateAnchorDialog from "@/views/cai/anchor/update-anchor-dialog";
import AnchorInfoDialog from "@/views/cai/anchor/anchor-info-dialog";
import AddAnchorTopDialog from '@/views/cai/anchorTop/add-anchor-top-dialog.vue'
import AnchorTopDialog from '@/views/cai/anchorTop/anchor-top-dialog.vue'

export default {
  name: "Anchor",
  components:{
    AddAnchorTopDialog,AnchorTopDialog,
    AddAnchorDialog,UpdateAnchorDialog,AnchorInfoDialog
  },
  data() {
    return {
      genderList,userStatusList,videoStatusList,onlineStatusList,
      systemName: process.env.VUE_APP_SYSTEM_HOME,
      addAnchorDialogVisible: false,
      updateAnchorDialogVisible: false,
      anchorInfoDialogVisible: false,
      addAnchorTopDialogVisible: false,
      anchorTopDialogVisible: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 女神列表表格数据
      anchorList: [],
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        usercode: undefined,
        mobile: undefined,
        onlineStatus: undefined,
        startPrice: undefined,
        endPrice: undefined
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    hiddenStatusRenderHeader(h,{column}) {
      return h('div',[
        h('span', column.label),
        h('el-tooltip',{undefined,
              props:{undefined,
                effect:'dark',
                content:"黑户主播火箭置顶后，首页别人无法看到，但是自己不受影响，且无法收到用户直播邀请",
                placement:'top',
              },
            },
            [h('i', {undefined,
              class: 'el-icon-question',
              style: "color:#409eff;margin-left:5px;cursor:pointer;"
            })],
            {content:"黑户主播火箭置顶后，首页别人无法看到，但是自己不受影响，且无法收到用户直播邀请"})

      ]);
    },
    /** 查询女神列表列表 */
    getList() {
      this.loading = true;
      listAnchor(this.queryParams).then(response => {
        this.anchorList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.queryParams.startPrice = undefined;
      this.queryParams.endPrice = undefined;
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    handleAdd(row) {
      this.addAnchorDialogVisible = true
      this.$nextTick(() => {
        this.$refs.addAnchorDialog.init(row?.usercode)
      })
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.updateAnchorDialogVisible = true
      this.$nextTick(() => {
        this.$refs.updateAnchorDialog.init(row)
      })
    },
    handleAnchorInfo(row){
      this.anchorInfoDialogVisible = true
      this.$nextTick(() => {
        this.$refs.anchorInfoDialog.init(row.userId)
      })
    },
    handleEnableGreetChange(row){
      let text = row.enableGreet === 0 ? '不允许' : '允许'
      this.$confirm('确认要' + text + '[' + row.nickname + ']使用群发吗?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        return updateAnchor({ id: row.id, enableGreet: row.enableGreet })
      }).then(() => {
        this.$modal.msgSuccess(text + '成功')
      }).catch(function() {
        row.enableGreet = row.enableGreet === 1 ? 0 : 1
      })
    },
    handleOpenVideoStatusChange(row){
      let text = row.openVideoStatus === 0 ? '封禁' : '恢复'
      this.$confirm('确认要' + text + '[' + row.nickname + ']开启视频吗?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        return updateAnchor({ id: row.id, openVideoStatus: row.openVideoStatus })
      }).then(() => {
        this.$modal.msgSuccess(text + '成功')
      }).catch(function() {
        row.openVideoStatus = row.openVideoStatus === 1 ? 0 : 1
      })
    },
    updateVideoStatusHandle(row){
      this.$confirm('确认把主播[' + row.nickname + ']状态切换为休闲吗?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        return updateVideoStatusOnline({ id: row.userId})
      }).then(() => {
        this.getList()
        this.$modal.msgSuccess('操作成功')
      }).catch(function() {
      })
    },
    handleIndexDisplayChange(row){
      let text = row.indexDisplay === 0 ? '封禁' : '恢复'
      this.$confirm('确认要' + text + '[' + row.nickname + ']首页展示吗?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        return updateAnchor({ id: row.id, indexDisplay: row.indexDisplay })
      }).then(() => {
        this.$modal.msgSuccess(text + '成功')
      }).catch(function() {
        row.indexDisplay = row.indexDisplay === 1 ? 0 : 1
      })
    },
    handleHiddenStatusChange(row){
      let text = row.hiddenStatus === 0 ? '关闭' : '开启'
      this.$confirm('确认要' + text + '[' + row.nickname + ']为黑户吗?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        return updateAnchor({ id: row.id, hiddenStatus: row.hiddenStatus })
      }).then(() => {
        this.$modal.msgSuccess(text + '成功')
      }).catch(function() {
        row.hiddenStatus = row.hiddenStatus === 1 ? 0 : 1
      })
    },
    handleRecommendStatusChange(row){
      let text = row.recommendStatus === 0 ? '封禁' : '恢复'
      this.$confirm('确认要' + text + '[' + row.nickname + ']是否被推荐吗?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        return updateAnchor({ id: row.id, recommendStatus: row.recommendStatus })
      }).then(() => {
        this.$modal.msgSuccess(text + '成功')
      }).catch(function() {
        row.recommendStatus = row.recommendStatus === 1 ? 0 : 1
      })
    },
    handleDelete(row) {
      this.$modal.confirm('是否确认取消"' + row.nickname + '"的主播？').then(() => {
        this.loading = true;
        return delAnchor(row.userId);
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("取消成功");
      }).catch(() => {
      }).finally(() => {
        this.loading = false;
      });
    },
    handleAnchorTop(){
      this.addAnchorTopDialogVisible = true
      this.$nextTick(() => {
        this.$refs.addAnchorTopDialog.init()
      })
    },
    handleAnchorTopList(){
      this.anchorTopDialogVisible = true
      this.$nextTick(() => {
        this.$refs.anchorTopDialog.init()
      })
    },

  }
};
</script>

<style lang="scss" scoped>
.click-class {
  cursor: pointer;
}
</style>
